@@ -5,6 +5,8 @@ use warnings;
 use examples;
 use POE;
 
+init();
+
 $channel->queue('one')->subscribe(sub {
     my $msg = shift;
     $amq->Logger->info("Queue 'one' received message '$msg'; sending 'pong' to queue 'two'");
@@ -27,9 +29,15 @@ POE::Session->create(
 
         ping => sub {
             my ($kernel, $heap) = @_[KERNEL, HEAP];
+            $kernel->delay(ping => 1);
+
+            if (! $amq->is_started) {
+                $amq->Logger->error("Server not started; not sending 'ping'");
+                return;
+            }
+
             $channel->queue('one')->publish('ping');
             $amq->Logger->info("Sending 'ping' to queue 'one'");
-            $kernel->delay(ping => 1);
         },
     },
 );
