@@ -41,7 +41,7 @@ use Carp;
 use base qw(Exporter Class::Accessor);
 __PACKAGE__->mk_accessors(qw(Logger is_stopped is_started is_stopping frame_max));
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 use constant {
     AMQP_ACK    => '__amqp_ack__',
@@ -455,7 +455,7 @@ sub compose_basic_publish {
     my $payload_size = length $payload;
     my @body_frames;
     while (length $payload) {
-        my $partial = substr $payload, 0, $self->frame_max, '';
+        my $partial = substr $payload, 0, $self->frame_max - 8, '';
         push @body_frames, Net::AMQP::Frame::Body->new(payload => $partial);
     }
 
